precision highp float;

uniform vec4 mainColor;
uniform vec4 gridColor;
uniform float gridSpacing; /// 0.3048 is 1ft and used as default value
uniform float conversionFactor; /// 1.0 / gridSpacing
uniform float lineThickness; /// defaults to 0.04

// Input variables for WebGL 1.0
varying vec3 v_position;

void main() {

    /// use mod to get a remainder away from our maximum grid spacing
    vec2 remainderXZ = mod(v_position.xz, gridSpacing);
    /// If spacing is 1.0 (a meter) this doesn't matter, but if you choose 1ft (0.3048), this converts our remainder to a percentage of a foot instead of a meter
    float convertedX = remainderXZ.x * conversionFactor;
    /// repeat for z-direction
    float convertedZ = remainderXZ.y * conversionFactor;

    float minThreshold = lineThickness * 0.5;
    float maxThreshold = 1.0 - minThreshold;

    if((convertedX >= maxThreshold || convertedX <= minThreshold) || (convertedZ >= maxThreshold || convertedZ <= minThreshold)){
        gl_FragColor = gridColor;
    } else {
        gl_FragColor = mainColor;
    }
}
